diff --git a/src/winio.c b/src/winio.c
index 05e07b06f268e0d535b22658e480d78d5f6b38f1..0c5cf624ae7108ffa8d041558ee124fa301406f5 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -1776,10 +1776,13 @@ int do_statusbar_input(bool *meta_key, bool *func_key, bool *s_or_t,
 
 			    do_statusbar_verbatim_input(&got_enter);
 
 			    /* If we got the Enter key, set finished to
 			     * TRUE to indicate that we're done. */
-			    if (got_enter)
+			    if (got_enter) {
+				input = NANO_ENTER_KEY;
 				*finished = TRUE;
+			    }
 			}
 			break;
 		    }
@@ -1776,10 +1776,13 @@ int do_statusbar_input(bool *meta_key, bool *func_key, bool *s_or_t,
 			    do_statusbar_verbatim_input(&got_enter);
 
-			    /* If we got the Enter key, set finished to
+			    /* If we got the Enter key, set input to the
+			     * key value for Enter, and set finished to
 			     * TRUE to indicate that we're done. */